<?php
/*
 * Example 2 - How to verify Mollie API Payments in a webhook.
 */

$cron=1;
require("../../../../scripts/main.php");

require('paynow.php');

try
{
	/*
	 * Initialize the Mollie API library with your API key.
	 *
	 * See: https://www.mollie.com/beheer/account/profielen/
	 */
	require_once 'mollie-api-php-1.2.7/src/Mollie/API/Autoloader.php';
    $mollie = new Mollie_API_Client;
    $mollie->setApiKey($payment_option_details['value']['apikey']['value']);

	/*
	 * Retrieve the payment's current state.
	 */
	$payment  = $mollie->payments->get($_POST["id"]);
	$order_id = $payment->metadata->order_id;


  	if ($payment->isPaid() == TRUE)
  	{
  		/*
  		 * At this point you'd probably want to start the process of delivering the product to the customer.
  		 */

        $order = new Order();

        $listing = new Listing(); // for updating any listings on order as paid

        // load order details
    	if ($order->getData($orderid)){

            // add payment to order
            $order->addPayment(0,'Paid via Mollie');

            // check if order is fully paid and update status to paid if so - only if status is unpaid or pending
            if ((!$order->status || $order->status==4) && !$order->getBalance()) $order->status=1;

            // check for any listings that need to be changed from unpaid status
            if (is_array($order->products)){
        		foreach($order->products as $order_slot_id => $orderSlot){
                    // check if there are listings in the order and set them to active
                    if (!empty($orderSlot->listing_id)){
                        if ($listing->getData($orderSlot->listing_id)){
                            if ($listing_->status!=1){
                                $listing->status=1;
                                if ($listing->saveItem())
                                    updateItemIndex('listings',array($listing->id));
                            }
                        }
                    }
        		}
    	    }

            if ($order->saveItem())
                update_item_list_file('orders',array($order->id));

            update_item_log('user',$order->owner,"Payment made via Mollie on order ".$order->id);

    		require_once(cms_root_dir.'plugins/PHPMailer/class.phpmailer.php');

    		// send email to customer
    		$mail = new PHPMailer();

            // send mail via smtp if set in config file
            if (smtp_host){
                require_once(cms_root_dir.'plugins/PHPMailer/class.smtp.php');
                $mail->IsSMTP(); // send via SMTP
                $mail->SMTPAuth = true; // turn on SMTP authentication
                $mail->SMTPSecure = 'ssl';
                $mail->Username = smtp_username; // SMTP username
                $mail->Password = smtp_password; // SMTP password
                $mail->Host       = smtp_host; // SMTP server
                $mail->Port       = smtp_port; // SMTP server
            }

    		$mail->From = $cmsSettings->config['site_email'];
    		$mail->FromName = cms_site_name;
    		$mail->AddAddress($order->customer->email);

    		$mail->Subject = "Order: ".$order_id.", Payment Received";
    		$mail->Body    = "Hi ".short_name($order->customer->name).",\n\nThank you for your payment. Your order is now being processed.\n\n".cms_site_name."\n".cms_url;


    		$mail->Send();

    		// send email to shop owner
    		$mail->ClearAddresses();
    		$mail->From = $cmsSettings->config['site_email'];
    		$mail->FromName = cms_site_name;
    		$mail->AddAddress($cmsSettings->config['site_email']);

    		$mail->Subject = "Order: $order_id, Payment Received";
    		$mail->Body    = "A payment was made via Mollie for order $order_id";


    		$mail->Send();

    	}
        else{
            update_log("Payment response from Mollie - warning: order ".$order_id." could not be found");
        }
  	}
  	elseif ($payment->isOpen() == FALSE)
  	{
  		/*
  		 * The payment isn't paid and isn't open anymore. We can assume it was aborted.
  		 */
         // do nothing
  	}

}
catch (Mollie_API_Exception $e)
{
	update_log("Mollie API call failed: " . htmlspecialchars($e->getMessage()));
}
